# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools da DevPro

Nesse curso é ensinado como contribuir com projetos de código aberto

[![Build Status](https://app.travis-ci.com/GermanUngo/libpythonpro.svg?branch=main)](https://app.travis-ci.com/GermanUngo/libpythonpro)

Suportada versão 3 de Python

Para instalar:

'''console
python3 -m venv .venv
source .venv/script/activate
pip install -r requirements-dev.txt
'''

Para conferir qualidade do codigo:

'''console
flake8
'''

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
